@@ -4,28 +4,37 @@ home = str(Path.home()) + '/'
 
 class config():
 
-	def __init(self):
+	def __init(self, prod_o_stag ):
+		if 'PROD' in prod_o_stag:
+			self.set_prod()
+		else:
+			self.set_stag()
 
-		cueServer = 'http://10.101.8.38:8080'
-		cueServer = 'https://cue.cue-test.rsi.ch:8080'
-		cueServer = 'http://18.158.61.219:8080'
+		for params in self._Environment_Variables.keys():
+			os.environ[param] = self._Environment_Variables[ param ]
+
+	def set_prod():
+
+		self.cueServer = 'http://10.101.8.38:8080'
+		self.cueServer = 'https://cue.cue-test.rsi.ch:8080'
+		self.cueServer = 'http://18.158.61.219:8080'
 		# ocio a http o https che ti manda il 301
 
-		cueServer = 'https://cue.cue-test.rsi.ch'
+		self.cueServer = 'https://cue.cue-test.rsi.ch'
 		# per l'admin
-		cueAdmin = 'https://admin.cue-test.rsi.ch'
+		self.cueAdmin = 'https://admin.cue-test.rsi.ch'
 
-		ecePresentation = 'http://presentation5.rsi.ch'
+		self.ecePresentation = 'http://presentation5.rsi.ch'
 		#ecePublishing = 'http://internal.publishing.production.rsi.ch'
 		# DEBUG PER ANDARE SOLO SUL pub3
-		ecePublishing = 'http://internal.publishing3.production.rsi.ch'
+		self.ecePublishing = 'http://internal.publishing3.production.rsi.ch'
 
-		cueServerProd = 'https://cue.cue.rsi.ch'
+		self.cueServerProd = 'https://cue.cue.rsi.ch'
 		# per l'admin
-		cueAdminProd = 'https://admin.cue.rsi.ch'
+		self.cueAdminProd = 'https://admin.cue.rsi.ch'
 
-		PROD_KAFKA_SERVERS =['rsis-zp-kafka1:9092','rsis-zp-kafka2:9092','rsis-zp-kafka3:9092']
-		PROD_Environment_Variables = {
+		self.KAFKA_SERVERS =['rsis-zp-kafka1:9092','rsis-zp-kafka2:9092','rsis-zp-kafka3:9092']
+		self._Environment_Variables = {
 			'AWS_DEFAULT_REGION':'eu-central-1',
 			'AWS_S3_BUCKET':'rsistatic-prd',
 			'AWS_S3_ACCESSKEY' : 'AKIAWKQD34FYKYBLIV7D', 
@@ -97,19 +106,21 @@ class config():
 
 		# PYTHONPATH=:/home/perucccl/PRODUCTION/import-keyframe/CUE:/home/perucccl/PRODUCTION/import-keyframe/MODULES:/home/perucccl/PRODUCTION/import-keyframe/Resources:/home/perucccl/PRODUCTION/import-keyframe/KAFKA:/home/perucccl/PRODUCTION/import-keyframe/ECE:/home/perucccl/PRODUCTION/import-keyframe/SOLR:/home/perucccl/PRODUCTION/import-keyframe/XML:/home/perucccl/PRODUCTION/import-keyframe/SQL
 
+	def set_stag():
 
-		cueServer = 'https://cue.cue-int.rsi.ch'
-		cueServer = 'http://cue-private-nlb-9efdfb5fe32811df.elb.eu-central-1.amazonaws.com:9080'
+		self.cueServer = 'https://cue.cue-int.rsi.ch'
+		self.cueServer = 'http://cue-private-nlb-9efdfb5fe32811df.elb.eu-central-1.amazonaws.com:9080'
 		# per l'admin
-		cueAdmin = 'https://admin.cue-int.rsi.ch'
+		self.cueAdmin = 'https://admin.cue-int.rsi.ch'
 		#ecePresentation = 'http://internal.presentation.staging.rsi.ch'
 		#ecePublishing = 'http://internal.publishing.staging.rsi.ch'
-		ecePresentation = 'http://presentation5.rsi.ch'
+		self.ecePresentation = 'http://presentation5.rsi.ch'
 		#ecePublishing = 'http://internal.publishing.production.rsi.ch'
-		ecePublishing = 'http://internal.publishing3.production.rsi.ch'
-		cueSolr = 'http://cue-private-nlb-9efdfb5fe32811df.elb.eu-central-1.amazonaws.com:9983'
+		self.ecePublishing = 'http://internal.publishing3.production.rsi.ch'
+		self.cueSolr = 'http://cue-private-nlb-9efdfb5fe32811df.elb.eu-central-1.amazonaws.com:9983'
 
-		STAG_Environment_Variables = {
+		self.KAFKA_SERVERS =['rsis-bs-kafka1:9092','rsis-bs-kafka2:9092','rsis-bs-kafka3:9092']
+		self._Environment_Variables = {
 			'AWS_DEFAULT_REGION':'eu-central-1',
 			'AWS_S3_BUCKET':'rsistatic-int',
 			'AWS_S3_ACCESSKEY' : 'AKIA4HLRXFHO7CIK7G73', 
