@@ -37,33 +37,25 @@ def SettaEnvironment( debug ):
         if (debug):
                 logger.debug( '---------------------------------')
 
-        Environment_Variables = {}
-
         logger.debug( 'verifico il setting della variabile _rsi_env_ ')
         if '_rsi_env_' in os.environ:
                 if 'PRODUCTION' in os.environ['_rsi_env_']:
                         logger.debug( 'variabile _rsi_env_ ha valore \'PRODUCTION\'')
                         logger.debug( 'setto ENV di PROD')
-                        Environment_Variables = pyConfig.PROD_Environment_Variables
+                        config = pyConfig.config('PROD')
                         pySettaVars.sectionMapping = pySettaVars.sectionMapping_PROD
                 else:
                         logger.debug( 'variabile _rsi_env_ ha valore : ' + os.environ['_rsi_env_'])
                         logger.debug( 'diverso da \'PRODUCTION\'')
                         logger.debug( 'setto ENV di STAG')
-                        Environment_Variables = pyConfig.STAG_Environment_Variables
+                        config = pyConfig.config('STAG')
                         pySettaVars.sectionMapping = pySettaVars.sectionMapping_STAG
 
         else:
                 logger.debug( 'variabile _rsi_env_ non trovata: setto ENV di STAG')
-                Environment_Variables = pyConfig.STAG_Environment_Variables
+		config = pyConfig.config('STAG')
                 pySettaVars.sectionMapping = pySettaVars.sectionMapping_STAG
 
-
-        for param in Environment_Variables.keys():
-                #logger.debug( "%20s %s" % (param,dict_env[param]))
-                os.environ[param] = Environment_Variables[ param ]
-
-
         if (debug):
                 logger.debug( 'DOPO AVER SETTATO ENVIRONMENT')
         if (debug):
